@@ -1,15 +1,17 @@
 import math
-from io import BytesIO
 from typing import List, Optional, Tuple
 
 import numpy as np
 import pandas as pd
+from minio import Minio
 from pandas.api.types import is_datetime64tz_dtype, is_object_dtype
 
 from exodusutils.constants import DATETIME_COMPONENTS_PREFIX
 from exodusutils.enums import DataType, TimeUnit
 from exodusutils.exceptions import ExodusBadRequest
+from exodusutils.exceptions.exceptions import ExodusError
 from exodusutils.schemas import Column
+from exodusutils.schemas.uri import MinioURI
 
 
 def cast_columns(
@@ -57,10 +59,12 @@ def cast_df_types(df: pd.DataFrame, feature_types: List[Column]) -> pd.DataFrame
     )
 
 
-def get_df(data: bytes, feature_types: List[Column]) -> pd.DataFrame:
-    return pd.DataFrame(
-        pd.read_csv(BytesIO(data), usecols=[f.name for f in feature_types])
-    ).pipe(cast_df_types, feature_types)
+def get_df(uri: MinioURI, client: Minio, feature_types: List[Column]) -> pd.DataFrame:
+    df = uri.get_df(client, header=[f.name for f in feature_types])
+    if df is None:
+        raise ExodusError(f"Failed to get data, uri = {uri.url}")
+    validate_columns(df.columns.to_list(), feature_types)
+    return df.pipe(cast_df_types, feature_types)
 
 
 def postfix_datetime_cols_with_time_components(col: str) -> List[str]:
