@@ -1,13 +1,14 @@
-from pandas import read_csv, DataFrame
+from pandas import DataFrame, read_csv
 from pydantic import BaseModel
 
-from exodusutils.schemas.uri import MinioURI, Minio, BytesIO
+from exodusutils.schemas.uri import BytesIO, Minio, MinioURI
 
 
 class InputFile(BaseModel):
     """
     The path to a local file user wishes to use as a task's input.
     """
+
     path: str
 
     @property
@@ -30,4 +31,3 @@ class InputFile(BaseModel):
 
     def delete(self, minio: Minio) -> None:
         minio.remove_object(self.uri.bucket, self.path)
-
