@@ -13,15 +13,6 @@ from exodusutils.schemas import Attribute
 from exodusutils.schemas.scores import CVScores, Scores
 from exodusutils.schemas.uri import MinioURI
 
-
-class Attributes(BaseModel):
-    cv_scores: CVScores
-    variable_importance: List[Attribute] = []
-    validation_scores: Optional[Scores] = None
-    holdout_scores: Optional[Scores] = None
-    threshold: Optional[float] = None
-
-
 class ModelRespBase(BaseModel, abc.ABC):
     """
     The base class for all model algorithm responses.
@@ -32,14 +23,7 @@ class TrainRespBody(ModelRespBase):
     """
     The schema for train response body.
     """
-
-    name: str = Field(description="The name of the model algorithm")
     model_id: str = Field(description="The specified model id")
-    hyperparameters: Dict[str, Any] = Field(description="The hyperparameters")
-    attributes: Attributes = Field(
-        description="The attributes, including CV scores, validation scores, etc."
-    )
-
 
 class PredictRespBody(ModelRespBase):
     """
@@ -67,8 +51,8 @@ class PredictRespBody(ModelRespBase):
         PredictRespBody
             The response body.
         """
-        key = f"prediction/{name}-{str(ObjectId())}.csv"
-        uri = MinioURI(bucket="exodus", key=key)
+        key = f"{name}-{str(ObjectId())}"
+        uri = MinioURI(bucket="prediction", key=key)
         return cls(prediction=uri.put_df(minio, df))
 
 
