@@ -96,7 +96,7 @@ class SimpleIIDTrainRequest(BaseModel):
             fold_assignment_column_name=meta_data.get(
                 "fold_assignment_column_name", None
             ),
-            random_seed=int(meta_data.get("random_seed", 9999))
+            random_seed=int(meta_data.get("random_seed", 9999)),
         )
         return Loaded(
             self.training_file, self.holdout_file, self.validation_file, req, minio
